==> GrapheR_1.9-60.tar.gz: GrapheR/R/load.GrapheR.R <==
load.GrapheR <-
function() {
  Env$img<-if (Env$lang=="en") {
    read.csv(file.path(.path.package("GrapheR"),"lang","Images_en.csv",fsep=.Platform$file.sep),header=FALSE,sep=";")
    } else if (Env$lang=="fr") {
    read.csv(file.path(.path.package("GrapheR"),"lang","Images_fr.csv",fsep=.Platform$file.sep),header=FALSE,sep=";")
    }
  Env$voc<-if (Env$lang=="en") {
    read.csv(file.path(.path.package("GrapheR"),"lang","Language_en.csv",fsep=.Platform$file.sep),header=FALSE,as.is=1,sep=";")
    } else if (Env$lang=="fr") {
    read.csv(file.path(.path.package("GrapheR"),"lang","Language_fr.csv",fsep=.Platform$file.sep),header=FALSE,as.is=1,sep=";")
    }
  Env$police<-tkfont.create(family="Arial",size=8)
  Env$police2<-tkfont.create(family="Arial",size=4)
  Env$police3<-tkfont.create(family="Arial",size=10,weight="bold")
  Env$police4<-tkfont.create(family="Courier",size=8)
  Env$police5<-tkfont.create(family="Arial",size=10)
  Env$police6<-tkfont.create(family="Arial",size=10,slant="italic")
  Env$dataset<-NULL
  Env$l.frames<-list()
  Env$l.frames$Fr1.status<-1
  Env$l.frames$Fr2.status<-0
  Env$l.frames$Fr3.status<-0
  Env$l.frames$Fr4.status<-0
  Env$l.frames$Fr5.status<-0
  Env$l.frames$Fr6.status<-0
  Env$l.fr1<-list()
  Env$l.fr2<-list()
  Env$l.fr3<-list()
  Env$l.fr4<-list()
  Env$l.fr5<-list()
  Env$l.fr6<-list()
  Env$l.fr7<-list()
  Env$l.lab<-list()
  Env$l.wdg<-list()
  Env$l.var<-list()
  Env$l.var$message<-tclVar("")
  Env$l.var$ecran<-"D"
  Env$l.var$extension<-tclVar("txt")
  Env$l.var$sepcol<-tclVar(Env$voc[5,1])
  Env$l.var$sepdec<-tclVar(Env$voc[9,1])
  Env$l.var$na<-tclVar("NA")
  Env$l.var$header<-tclVar(1)
  Env$l.var$regroup1<-tclVar(0)
  Env$l.var$regroup2<-tclVar("long")
  Env$l.var$regroup3<-tclVar("2")
  Env$l.var$var.num<-""
  Env$l.var$var.fact<-""
  Env$l.var$variable<-tclVar("")
  Env$l.var$facteur1<-tclVar("")
  Env$l.var$niveau<-tclVar("")
  Env$l.var$hist.type<-tclVar("")
  Env$l.var$encadre<-tclVar(0)
  Env$l.var$titre<-tclVar("")
  Env$l.var$titre.col<-tclVar("black")
  Env$l.var$titre.taille<-tclVar("1.5")
  Env$l.var$graduations.col<-tclVar("black")
  Env$l.var$graduations.taille<-tclVar("1")
  Env$l.var$legendes.col<-tclVar("black")
  Env$l.var$legendes.taille<-tclVar("1")
  Env$l.var$titre.axehor<-tclVar("")
  Env$l.var$titre.axever<-tclVar("")
  Env$l.var$liminf.axehor<-tclVar("Auto")
  Env$l.var$limsup.axehor<-tclVar("Auto")
  Env$l.var$liminf.axever<-tclVar("Auto")
  Env$l.var$limsup.axever<-tclVar("Auto")
  Env$l.var$log.axehor<-tclVar(0)
  Env$l.var$log.axever<-tclVar(0)
  Env$l.var$hist.barres<-tclVar("Auto")
  Env$l.var$couleur1A<-tclVar("white")
  Env$l.var$col.borduresA<-tclVar("black")
  Env$l.var$hist.dens<-tclVar(0)
  Env$l.var$couleur2A<-tclVar("black")
  Env$l.var$trait1<-tclVar("")
  Env$l.var$epaisseur1<-tclVar("1")
  Env$l.var$box.orient<-tclVar("")
  Env$l.var$titre.axenoms<-tclVar("")
  Env$l.var$titre.axevaleurs<-tclVar("")
  Env$l.var$liminf.axevaleurs<-tclVar("Auto")
  Env$l.var$limsup.axevaleurs<-tclVar("Auto")
  Env$l.var$log.axevaleurs<-tclVar(0)
  Env$l.var$ICmediane<-tclVar(0)
  Env$l.var$lg.moustaches<-tclVar("1.5")
  Env$l.var$outliers<-tclVar(1)
  Env$l.var$couleur3<-tclVar("black")
  Env$l.var$box.symbol<-tclVar("")
  Env$l.var$noms1<-""
  Env$l.var$moyprop<-tclVar("moy")
  Env$l.var$facteur2<-tclVar("")
  Env$l.var$proportions<-tclVar("")
  Env$l.var$prop.niveaux<-tclVar("")
  Env$l.var$nomsprop<-""
  Env$l.var$moyprop<-tclVar("moy")
  Env$l.var$facteurprop<-tclVar("")
  Env$l.var$couleur1B<-"grey"
  Env$l.var$col.borduresB<-"black"
  Env$l.var$hachuresA<-tclVar("1")
  Env$l.var$hachuresB<-1
  Env$l.var$stack<-tclVar(0)
  Env$l.var$erreur<-tclVar("")
  Env$l.var$legende<-tclVar(0)
  Env$l.var$legende.pos<-tclVar("")
  Env$l.var$legende.titre<-tclVar("")
  Env$l.var$noms2<-""
  Env$l.var$plusieurs<-tclVar(0)
  Env$l.var$nomsprop.fac<-""
  Env$l.var$cam.orient<-tclVar("")
  Env$l.var$cam.start<-tclVar("0")
  Env$l.var$cam.lien<-tclVar(0)
  Env$l.var$parts.niveaux<-tclVar("")
  Env$l.var$nomsparts<-""
  Env$l.var$varX<-tclVar("")
  Env$l.var$varY<-tclVar("")
  Env$l.var$varX.prop<-tclVar("")
  Env$l.var$couleur2B<-"grey"
  Env$l.var$taille.ptsA<-tclVar("1")
  Env$l.var$taille.ptsB<-1
  Env$l.var$type.courbeA<-tclVar("")
  Env$l.var$type.courbeB<-""
  Env$l.var$trait2<-""
  Env$l.var$epaisseur2<-1
  Env$l.var$symboleA<-tclVar("1")
  Env$l.var$symboleB<-1
  Env$l.var$select<-1
  Env$l.var$droiteA<-tclVar("")
  Env$l.var$droiteB<-""
  Env$l.var$nw.col<-tclVar("white")
  Env$l.var$nw.lignes<-tclVar("1")
  Env$l.var$nw.colonnes<-tclVar("1")
  Env$l.var$add.abscisses<-NULL
  Env$l.var$add.hauteurs<-NULL
  Env$l.var$add.param1<-tclVar("")
  Env$l.var$add.param2<-tclVar("")
  Env$l.var$add.param3<-tclVar("")
  Env$l.var$add.trait<-tclVar("")
  Env$l.var$add.epaisseur1<-tclVar("1")
  Env$l.var$add.col1<-tclVar("black")
  Env$l.var$add.distrib<-tclVar("norm")
  Env$l.var$add.seq<-NULL
  Env$l.var$add.seq2<-NULL
  Env$l.var$add.txt<-tclVar("")
  Env$l.var$add.epaisseur2<-tclVar("1")
  Env$l.var$add.col2<-tclVar("black")
  Env$l.var$add.matrice<-NULL
  Env$l.var$fen.num<-tclVar("")
  Env$l.var$fen.larg<-tclVar("600")
  Env$l.var$fen.type<-tclVar("jpg")
  ouvrir.GrapheR()
}

==> GrapheR_1.9-71.tar.gz: GrapheR/R/load.GrapheR.R <==
load.GrapheR <-
function() {
  Env$img<-if (Env$lang=="en") {
    read.csv(file.path(.path.package("GrapheR"),"lang","Images_en.csv",fsep=.Platform$file.sep),header=FALSE,sep=";")
    } else if (Env$lang=="fr") {
    read.csv(file.path(.path.package("GrapheR"),"lang","Images_fr.csv",fsep=.Platform$file.sep),header=FALSE,sep=";")
    } else if (Env$lang=="es") {
    read.csv(file.path(.path.package("GrapheR"),"lang","Images_es.csv",fsep=.Platform$file.sep),header=FALSE,sep=";")
    }
  Env$voc<-if (Env$lang=="en") {
    read.csv(file.path(.path.package("GrapheR"),"lang","Language_en.csv",fsep=.Platform$file.sep),header=FALSE,as.is=1,sep=";")
    } else if (Env$lang=="fr") {
    read.csv(file.path(.path.package("GrapheR"),"lang","Language_fr.csv",fsep=.Platform$file.sep),header=FALSE,as.is=1,sep=";")
    } else if (Env$lang=="es") {
    read.csv(file.path(.path.package("GrapheR"),"lang","Language_es.csv",fsep=.Platform$file.sep),header=FALSE,as.is=1,sep=";")
    }
  Env$police<-tkfont.create(family="Arial",size=8)
  Env$police2<-tkfont.create(family="Arial",size=4)
  Env$police3<-tkfont.create(family="Arial",size=10,weight="bold")
  Env$police4<-tkfont.create(family="Courier",size=8)
  Env$police5<-tkfont.create(family="Arial",size=10)
  Env$police6<-tkfont.create(family="Arial",size=10,slant="italic")
  Env$dataset<-NULL
  Env$l.frames<-list()
  Env$l.frames$Fr1.status<-1
  Env$l.frames$Fr2.status<-0
  Env$l.frames$Fr3.status<-0
  Env$l.frames$Fr4.status<-0
  Env$l.frames$Fr5.status<-0
  Env$l.frames$Fr6.status<-0
  Env$l.fr1<-list()
  Env$l.fr2<-list()
  Env$l.fr3<-list()
  Env$l.fr4<-list()
  Env$l.fr5<-list()
  Env$l.fr6<-list()
  Env$l.fr7<-list()
  Env$l.lab<-list()
  Env$l.wdg<-list()
  Env$l.var<-list()
  Env$l.var$message<-tclVar("")
  Env$l.var$ecran<-"D"
  Env$l.var$extension<-tclVar("txt")
  Env$l.var$sepcol<-tclVar(Env$voc[5,1])
  Env$l.var$sepdec<-tclVar(Env$voc[9,1])
  Env$l.var$na<-tclVar("NA")
  Env$l.var$header<-tclVar(1)
  Env$l.var$regroup1<-tclVar(0)
  Env$l.var$regroup2<-tclVar("long")
  Env$l.var$regroup3<-tclVar("2")
  Env$l.var$var.num<-""
  Env$l.var$var.fact<-""
  Env$l.var$variable<-tclVar("")
  Env$l.var$facteur1<-tclVar("")
  Env$l.var$niveau<-tclVar("")
  Env$l.var$hist.type<-tclVar("")
  Env$l.var$encadre<-tclVar(0)
  Env$l.var$titre<-tclVar("")
  Env$l.var$titre.col<-tclVar("black")
  Env$l.var$titre.taille<-tclVar("1.5")
  Env$l.var$graduations.col<-tclVar("black")
  Env$l.var$graduations.taille<-tclVar("1")
  Env$l.var$legendes.col<-tclVar("black")
  Env$l.var$legendes.taille<-tclVar("1")
  Env$l.var$titre.axehor<-tclVar("")
  Env$l.var$titre.axever<-tclVar("")
  Env$l.var$liminf.axehor<-tclVar("Auto")
  Env$l.var$limsup.axehor<-tclVar("Auto")
  Env$l.var$liminf.axever<-tclVar("Auto")
  Env$l.var$limsup.axever<-tclVar("Auto")
  Env$l.var$log.axehor<-tclVar(0)
  Env$l.var$log.axever<-tclVar(0)
  Env$l.var$hist.barres<-tclVar("Auto")
  Env$l.var$couleur1A<-tclVar("white")
  Env$l.var$col.borduresA<-tclVar("black")
  Env$l.var$hist.dens<-tclVar(0)
  Env$l.var$couleur2A<-tclVar("black")
  Env$l.var$trait1<-tclVar("")
  Env$l.var$epaisseur1<-tclVar("1")
  Env$l.var$facteur.interaction<-""
  Env$l.var$box.orient<-tclVar("")
  Env$l.var$titre.axenoms<-tclVar("")
  Env$l.var$titre.axevaleurs<-tclVar("")
  Env$l.var$liminf.axevaleurs<-tclVar("Auto")
  Env$l.var$limsup.axevaleurs<-tclVar("Auto")
  Env$l.var$log.axevaleurs<-tclVar(0)
  Env$l.var$ICmediane<-tclVar(0)
  Env$l.var$lg.moustaches<-tclVar("1.5")
  Env$l.var$outliers<-tclVar(1)
  Env$l.var$couleur3<-tclVar("black")
  Env$l.var$box.symbol<-tclVar("")
  Env$l.var$noms1<-""
  Env$l.var$moyprop<-tclVar("moy")
  Env$l.var$facteur2<-tclVar("")
  Env$l.var$proportions<-tclVar("")
  Env$l.var$prop.niveaux<-tclVar("")
  Env$l.var$nomsprop<-""
  Env$l.var$moyprop<-tclVar("moy")
  Env$l.var$facteurprop<-tclVar("")
  Env$l.var$couleur1B<-"grey"
  Env$l.var$col.borduresB<-"black"
  Env$l.var$hachuresA<-tclVar("1")
  Env$l.var$hachuresB<-1
  Env$l.var$stack<-tclVar(0)
  Env$l.var$erreur<-tclVar("")
  Env$l.var$legende<-tclVar(0)
  Env$l.var$legende.pos<-tclVar("")
  Env$l.var$legende.titre<-tclVar("")
  Env$l.var$noms2<-""
  Env$l.var$plusieurs<-tclVar(0)
  Env$l.var$nomsprop.fac<-""
  Env$l.var$cam.orient<-tclVar("")
  Env$l.var$cam.start<-tclVar("0")
  Env$l.var$cam.lien<-tclVar(0)
  Env$l.var$parts.niveaux<-tclVar("")
  Env$l.var$nomsparts<-""
  Env$l.var$varX<-tclVar("")
  Env$l.var$varY<-tclVar("")
  Env$l.var$varX.prop<-tclVar("")
  Env$l.var$couleur2B<-"grey"
  Env$l.var$taille.ptsA<-tclVar("1")
  Env$l.var$taille.ptsB<-1
  Env$l.var$type.courbeA<-tclVar("")
  Env$l.var$type.courbeB<-""
  Env$l.var$trait2<-""
  Env$l.var$epaisseur2<-1
  Env$l.var$symboleA<-tclVar("1")
  Env$l.var$symboleB<-1
  Env$l.var$select<-1
  Env$l.var$droiteA<-tclVar("")
  Env$l.var$droiteB<-""
  Env$l.var$nw.col<-tclVar("white")
  Env$l.var$nw.lignes<-tclVar("1")
  Env$l.var$nw.colonnes<-tclVar("1")
  Env$l.var$add.abscisses<-NULL
  Env$l.var$add.hauteurs<-NULL
  Env$l.var$add.param1<-tclVar("")
  Env$l.var$add.param2<-tclVar("")
  Env$l.var$add.param3<-tclVar("")
  Env$l.var$add.trait<-tclVar("")
  Env$l.var$add.epaisseur1<-tclVar("1")
  Env$l.var$add.col1<-tclVar("black")
  Env$l.var$add.distrib<-tclVar("norm")
  Env$l.var$add.seq<-NULL
  Env$l.var$add.seq2<-NULL
  Env$l.var$add.txt<-tclVar("")
  Env$l.var$add.epaisseur2<-tclVar("1")
  Env$l.var$add.col2<-tclVar("black")
  Env$l.var$add.matrice<-NULL
  Env$l.var$fen.num<-tclVar("")
  Env$l.var$fen.larg<-tclVar("600")
  Env$l.var$fen.type<-tclVar("jpg")
  Env$l.code<-list()
  Env$l.code$ask<-FALSE
  Env$l.code$save<-FALSE
  Env$l.code$folder<-NULL
  Env$l.code$graphsnb<-0
  Env$l.code$graphsnb<-0
  Env$l.code$x.inf<-NULL
  Env$l.code$x.sup<-NULL
  Env$l.code$y.inf<-NULL
  Env$l.code$y.sup<-NULL
  ouvrir.GrapheR()
}
